pub enum Branch<A, B> {
First(A),
Second(B),
}Expand description
A first-class two-way branching transition result.
This lets a transition expose two concrete machine targets while keeping the branch alternatives visible to Statum introspection.
Variants