MachineRole

Enum MachineRole 

pub enum MachineRole {
    Protocol,
    Composition,
}
Whether one machine family is a local protocol machine or a higher-level composition machine.

Variants



Protocol

Ordinary local protocol machine.



Composition

Higher-level machine that composes other machines or exact handoff evidence into one workspace flow.