pub fn linked_relations() -> &'static [LinkedRelationDescriptor]Expand description
Returns every linked exact relation record visible to the current build.
pub fn linked_relations() -> &'static [LinkedRelationDescriptor]Returns every linked exact relation record visible to the current build.