pub enum ProjectionError<E> {
EmptyInput,
Reducer(E),
}Expand description
Errors returned by projection helpers.
Variants
EmptyInput
The reducer was asked to fold an empty stream.
Reducer(E)
The reducer rejected one of the events in the stream.