ProjectionReducer

Trait ProjectionReducer 

pub trait ProjectionReducer<Event> {
    type Projection;
    type Error;

    // Required methods
    fn seed(&self, event: &Event) -> Result<Self::Projection, Self::Error>;
    fn apply(
        &self,
        projection: &mut Self::Projection,
        event: &Event,
    ) -> Result<(), Self::Error>;
}
Fold events into a projection that can later be rehydrated with #[validators].

Required Associated Types

type Projection

The output projection type.

type Error

The reducer-specific error type.

Required Methods

fn seed(&self, event: &Event) -> Result<Self::Projection, Self::Error>

Create the first projection value from the first event in a stream.

fn apply( &self, projection: &mut Self::Projection, event: &Event, ) -> Result<(), Self::Error>

Apply a later event to an existing projection value.

Implementors