LinkedStateDescriptor

Struct LinkedStateDescriptor 

pub struct LinkedStateDescriptor {
    pub rust_name: &'static str,
    pub label: Option<&'static str>,
    pub description: Option<&'static str>,
    pub docs: Option<&'static str>,
    pub has_data: bool,
    pub direct_construction_available: bool,
}
Erased state descriptor carried by the linked machine inventory.

Fields

rust_name: &'static str

Rust variant name of the state marker.

label: Option<&'static str>

Optional human-facing state label.

description: Option<&'static str>

Optional human-facing state description.

docs: Option<&'static str>

Optional longer-form source documentation from outer rustdoc comments.

has_data: bool

Whether the state carries state_data.

direct_construction_available: bool

Whether the machine exposes direct construction for this state.