LinkedViaRouteDescriptor

Struct LinkedViaRouteDescriptor 

pub struct LinkedViaRouteDescriptor {
    pub machine: MachineDescriptor,
    pub via_module_path: &'static str,
    pub route_name: &'static str,
    pub resolved_route_type_name: fn() -> &'static str,
    pub route_id: u64,
    pub transition: &'static str,
    pub source_state: &'static str,
    pub target_state: &'static str,
}
One producer transition that can generate an attested route value.

Fields

machine: MachineDescriptor

Rust-facing identity of the producer machine family.

via_module_path: &'static str

Machine-module path that owns the generated machine::via namespace.

route_name: &'static str

Human-facing route name, such as Capture.

resolved_route_type_name: fn() -> &'static str

Compiler-resolved route marker type identity used to join producer inventories with consumer #[via(...)] declarations.

route_id: u64

Stable route id shared with LinkedRelationTarget::AttestedRoute.

transition: &'static str

Rust transition method name on the producer machine.

source_state: &'static str

Exact producer source state.

target_state: &'static str

Exact producer target state.