pub struct RecordedTransition<S: 'static, T: 'static> {
pub machine: MachineDescriptor,
pub from: S,
pub transition: T,
pub chosen: S,
}Expand description
A runtime record of one chosen transition.
Fields
machine: MachineDescriptorRust-facing identity of the machine family.
from: SExact source state where the transition was taken.
transition: TExact transition site that was chosen.
chosen: SExact target state that actually happened at runtime.
Implementations
Sourceimpl<S, T> RecordedTransition<S, T>where
S: 'static,
T: 'static,
impl<S, T> RecordedTransition<S, T>where
S: 'static,
T: 'static,
Sourcepub const fn new(
machine: MachineDescriptor,
from: S,
transition: T,
chosen: S,
) -> Self
pub const fn new( machine: MachineDescriptor, from: S, transition: T, chosen: S, ) -> Self
Builds a runtime transition record from typed machine ids.
Sourcepub fn transition_in<'a>(
&self,
graph: &'a MachineGraph<S, T>,
) -> Option<&'a TransitionDescriptor<S, T>>
pub fn transition_in<'a>( &self, graph: &'a MachineGraph<S, T>, ) -> Option<&'a TransitionDescriptor<S, T>>
Finds the static transition descriptor for this runtime event.
Sourcepub fn source_state_in<'a>(
&self,
graph: &'a MachineGraph<S, T>,
) -> Option<&'a StateDescriptor<S>>
pub fn source_state_in<'a>( &self, graph: &'a MachineGraph<S, T>, ) -> Option<&'a StateDescriptor<S>>
Finds the static source-state descriptor for this runtime event.
Sourcepub fn chosen_state_in<'a>(
&self,
graph: &'a MachineGraph<S, T>,
) -> Option<&'a StateDescriptor<S>>
pub fn chosen_state_in<'a>( &self, graph: &'a MachineGraph<S, T>, ) -> Option<&'a StateDescriptor<S>>
Finds the static chosen-target descriptor for this runtime event.