pub enum LinkedRelationBasis {
DirectTypeSyntax,
AttestedTypeSyntax,
DeclaredReferenceType,
ViaDeclaration,
}Expand description
Why one exact relation was inferred.
Variants
DirectTypeSyntax
The target was visible directly in the scanned type syntax.
AttestedTypeSyntax
The target came from a canonical statum::Attested<_, Route> wrapper
visible directly in the scanned type syntax.
DeclaredReferenceType
The scanned type resolved through one declared reference type.
ViaDeclaration
The target was declared explicitly through #[via(...)].