pub enum LinkedRelationKind {
StatePayload,
MachineField,
TransitionParam,
}Expand description
Exact relation kinds exported by the linked build.
Variants
StatePayload
A state payload type points at another machine state.
MachineField
A machine struct field type points at another machine state.
TransitionParam
A transition parameter type points at another machine state.