pub struct RebuildReport<M> {
pub attempts: Vec<RebuildAttempt>,
pub result: Result<M>,
}Expand description
A typed rehydration result plus the validator attempts that produced it.
Fields
attempts: Vec<RebuildAttempt>Validator attempts in evaluation order.
result: Result<M>Final rebuild result.
Implementations
Sourceimpl<M> RebuildReport<M>
impl<M> RebuildReport<M>
Sourcepub fn matched_attempt(&self) -> Option<&RebuildAttempt>
pub fn matched_attempt(&self) -> Option<&RebuildAttempt>
Returns the first matching validator attempt, if any.
Sourcepub fn into_result(self) -> Result<M>
pub fn into_result(self) -> Result<M>
Consumes the report and returns the original rebuild result.