StateMarker

Trait StateMarker 

pub trait StateMarker {
    type Data;
}
A generated state marker type.

Every #[state] variant produces one marker type that implements StateMarker. The associated Data type is () for unit states and the tuple payload type for data-bearing states.

Required Associated Types

type Data

The payload type stored in machines for this state.

Implementors